@@ -5,7 +5,8 @@
     :url: https://blog.farmer233.top
     :date: 2021/09/02 22:20:52
 '''
-
+from typing import Dict, Union
+import requests
 from school_sdk.client.api.score import Score
 from school_sdk.client.api.user_info import Info
 from school_sdk.config import URL_ENDPOINT
@@ -13,14 +14,14 @@ from school_sdk.client.api.schedules import Schedule
 from school_sdk.client.exceptions import LoginException
 import time
 from school_sdk.client.api.login import ZFLogin
-from school_sdk.client.base import BaseSchoolClient
+from school_sdk.client.base import BaseUserClient
 
 
 class SchoolClient():
 
-    def __init__(self, host, port:int=80, ssl:bool=False, name=None, exist_verify:bool=False,
-                lan_host=None, lan_port=80, timeout=10,
-                login_url_path=None, url_endpoints=None) -> None:
+    def __init__(self, host, port: int = 80, ssl: bool = False, name=None, exist_verify: bool = False,
+                 captcha_type: str = "captcha", retry: int = 10, lan_host=None, lan_port=80, timeout=10,
+                 login_url_path=None, url_endpoints=None) -> None:
         """初始化学校配置
 
         Args:
@@ -28,7 +29,12 @@ class SchoolClient():
             port (int, optional): 端口号. Defaults to 80.
             ssl (bool, optional): 是否启用HTTPS. Defaults to False.
             name (str, optional): 学校名称. Defaults to None.
+
             exist_verify (bool, optional): 是否有验证码. Defaults to False.
+            captcha_type (str, optional): 验证码类型. Defaults to captcha. 
+                    滑块传入cap开头, 图片传入kap开头 与教务系统的url地址对应, 默认识别滑块验证码.
+            retry (int, optional): 登录重试次数. Defaults to 10.
+
             lan_host (str, optional): 内网主机地址. Defaults to None.
             lan_port (int, optional): 内网主机端口号. Defaults to 80.
             timeout (int, optional): 请求超时时间. Defaults to 10.
@@ -38,6 +44,8 @@ class SchoolClient():
         school = {
             "name": name,
             "exist_verify": exist_verify,
+            "captcha_type": captcha_type,
+            "retry": retry,
             "lan_host": lan_host,
             "lan_port": lan_port,
             "timeout": timeout,
@@ -46,9 +54,9 @@ class SchoolClient():
         }
 
         self.base_url = f'https://{host}:{port}' if ssl else f'http://{host}:{port}'
-        self.config = school
-    
-    def user_login(self, account:str, password:str, **kwargs):
+        self.config: dict = school
+
+    def user_login(self, account: str, password: str, **kwargs):
         """用户登录
 
         Args:
@@ -58,9 +66,14 @@ class SchoolClient():
         user = UserClient(self, account=account, password=password, **kwargs)
         return user.login()
 
+    def init_dev_user(self, cookies: str = None):
+        dev_user = UserClient(self, account="dev account",
+                              password="dev password")
+        return dev_user.get_dev_user(cookies)
 
-class UserClient(BaseSchoolClient):
-    schedule:Schedule = None
+
+class UserClient(BaseUserClient):
+    schedule: Schedule = None
     score: Score = None
     info = None
 
@@ -84,8 +97,8 @@ class UserClient(BaseSchoolClient):
         """用户登录，通过SchoolClient调用
         """
         user = ZFLogin(user_client=self)
-        user.get_raw_csrf_and_cookie()
-        user.get_rsa_publick_key()
+        # user.get_raw_csrf_and_cookie()
+        # user.get_rsa_publick_key()
         try:
             user.get_login()
             self._http = user._http
@@ -98,16 +111,38 @@ class UserClient(BaseSchoolClient):
             self.schedule = Schedule(self)
 
     def get_schedule(self, **kwargs):
+        """获取课表"""
         if self.schedule is None:
             self.schedule = Schedule(self)
         return self.schedule.get_schedule_dict(**kwargs)
-    
+
     def get_score(self, **kwargs):
+        """获取成绩"""
         if self.score is None:
             self.score = Score(self)
         return self.score.get_score(**kwargs)
 
     def get_info(self, **kwargs):
+        """获取个人信息"""
         if self.info is None:
             self.info = Info(self)
         return self.info.get_info(**kwargs)
+
+    # dev options
+    def get_cookies(self):
+        return self._http.cookies
+
+    def set_cookies(self, cookies: str, **kwargs):
+        """设置user cookies
+
+        Args:
+            cookies (str): Cookies 字符串
+        """
+        cookies = cookies.strip()
+        key, value = cookies.split('=')
+        self._http.cookies.set(key, value)
+
+    def get_dev_user(self, cookies: str, **kwargs):
+        self._http = requests.Session()
+        self.set_cookies(cookies=cookies, **kwargs)
+        return self
